Package: SMAD
Type: Package
Title: Statistical Modelling of AP-MS Data (SMAD)
Version: 1.27.0
Authors@R: c(
    person("Qingzhou", "Zhang", , "zqzneptune@hotmail.com", c("aut", "cre")))
Description: Assigning probability scores to protein interactions captured in 
    affinity purification mass spectrometry (AP-MS) expriments to infer 
    protein-protein interactions. The output would facilitate non-specific 
    background removal as contaminants are commonly found in AP-MS data.
Depends: R (>= 3.6.0), RcppAlgos
Imports: magrittr (>= 1.5), dplyr, stats, tidyr, utils, Rcpp (>= 1.0.0)
LinkingTo: Rcpp
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.1.0
Suggests: knitr, rmarkdown, testthat, BiocStyle
VignetteBuilder: knitr
biocViews: MassSpectrometry, Proteomics, Software
git_url: https://git.bioconductor.org/packages/SMAD
git_branch: devel
git_last_commit: 3337822
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.23
Date/Publication: 2025-10-30
NeedsCompilation: yes
Packaged: 2025-10-30 23:06:55 UTC; biocbuild
Author: Qingzhou Zhang [aut, cre]
Maintainer: Qingzhou Zhang <zqzneptune@hotmail.com>
