# Generated by roxygen2: do not edit by hand

export(CompPASS)
export(DICE)
export(HG)
export(Hart)
export(PE)
exportPattern('^[[:alpha:]]+')
import(Rcpp)
importFrom(Rcpp,evalCpp)
importFrom(RcppAlgos,comboGeneral)
importFrom(dplyr,bind_rows)
importFrom(dplyr,filter)
importFrom(dplyr,group_by)
importFrom(dplyr,left_join)
importFrom(dplyr,mutate)
importFrom(dplyr,n)
importFrom(dplyr,summarise)
importFrom(magrittr,"%>%")
importFrom(stats,phyper)
importFrom(stats,quantile)
importFrom(stats,setNames)
importFrom(tidyr,separate)
importFrom(tidyr,spread)
importFrom(utils,unstack)
useDynLib(SMAD)
