# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

.GetDICE <- function(mat) {
    .Call('_SMAD_GetDICE', PACKAGE = 'SMAD', mat)
}

.GetPPN <- function(mat) {
    .Call('_SMAD_GetPPN', PACKAGE = 'SMAD', mat)
}

