#' Test data for SMAD 
#'
#' \itemize{
#'   \item idRun A unique identifier for one AP-MS run
#'   \item idBait A unique identifier for the bait protein
#'   \item idPrey A unique identifier for the prey protein
#'   \item countPrey Sepctra/Peptider count for the prey protein
#'   \item lenPrey Protein length for the prey protein
#' }
#' @description It is a subset of unfiltered BioPlex 2.0 consisting of
#' apoptosis as bait proteins
#' @docType data
#' @keywords datasets
#' @name TestDatInput 
#' @usage data(TestDatInput)
#' @format A data frame with 5000 rows and 5 variables
NULL